/*
 * Copyright (C) 2004 emuWorks
 * http://games.technoplaza.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package chtdecoder.datastructures;

import java.util.Enumeration;
import java.util.NoSuchElementException;
import java.util.Vector;

/**
 * A concrete implementation of the CHTCodeList interface.
 *
 * @author John David Ratliff
 * @version 1.1, 09/14/04
 */
class BasicCHTCodeList extends AbstractCHTCodeList {
    /**
     * Creates a new BasicCHTCodeList object.
     */
    protected BasicCHTCodeList() {
        // restrict to class access only
        vector = new Vector();
    }

    /**
     * Returns a String representation of this CHTCodeList.
     *
     * @return A String representation.
     */
    public String toString() {
        return "BasicCHTCodeList[size=" + size() + "]";
    }

    /**
     * A concrete implementation of the CHTCodeIterator interface.
     *
     * @author John David Ratliff
     * @version 1.2, 10/22/04
     */
    public static class BasicCHTCodeIterator implements CHTCodeIterator {
        private Enumeration enumeration;
        private int elements;

        /**
         * Creates a new BasicCHTCodeIterator object.
         *
         * @param enumeration The enumeration the CHTCode objects are in.
         * @param elements Total elements in the enumeration.
         */
        public BasicCHTCodeIterator(Enumeration enumeration, int elements) {
            this.enumeration = enumeration;
            this.elements = elements;
        }

        /**
         * Queries if this iterator has more elements.
         *
         * @return true if more elements remain; false otherwise.
         */
        public boolean hasMore() {
            return this.enumeration.hasMoreElements();
        }

        /**
         * Gets the next CHTCode from this iterator.
         *
         * @return The next CHTCode in this iterator.
         *
         * @throws NoSuchElementException if no more elements are in this
         *         iterator.
         */
        public CHTCode next() throws NoSuchElementException {
            CHTCode code = (CHTCode)this.enumeration.nextElement();
            elements--;

            return code;
        }

        /**
         * Returns the number of items remaining in this CHTCodeIterator.
         *
         * @return The remaining item count.
         */
        public int remain() {
            return this.elements;
        }

        /**
         * Returns a String representation of this iterator.
         *
         * @return A String representation.
         */
        public String toString() {
            return "BasicCHTCodeIterator";
        }
    }
}
