/*
 * Copyright (C) 2004 emuWorks
 * http://games.technoplaza.net/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package chtdecoder.datastructures;

/**
 * A List for storing CHTCode objects.
 *
 * @author John David Ratliff
 * @version 1.1, 09/14/04
 */
public interface CHTCodeList {
    /**
     * Adds a CHTCode to the end of this list.
     *
     * @param code the CHTCode to add.
     */
    public void add(CHTCode code);

    /**
     * Removes a CHTCode from this list at position index.
     *
     * @param index The position in the list to remove.
     *
     * @return The removed CHTCode object.
     *
     * @throws ArrayIndexOutOfBoundsException if the index in not valid (0
     *         &lt; index &lt; size())
     */
    public CHTCode remove(int index) throws ArrayIndexOutOfBoundsException;

    /**
     * Gets a CHTCode from this list.
     *
     * @param index The index of the CHTCode to get.
     *
     * @return The CHTCode.
     *
     * @throws ArrayIndexOutOfBoundsException if the index in not valid (0
     *         &lt; index &lt; size())
     */
    public CHTCode get(int index) throws ArrayIndexOutOfBoundsException;

    /**
     * Gets the size of this list (the element count).
     *
     * @return The number of elements in this list.
     */
    public int size();

    /**
     * Queries if this list is empty.
     *
     * @return true if this list is empty; false otherwise.
     */
    public boolean isEmpty();

    /**
     * Gets an iterator for the elements in this list.
     *
     * @return The CHTCodeIterator.
     */
    public CHTCodeIterator iterator();
}
